# Go项目
## 云计算
### 容器
- [moby](https://github.com/moby/moby): Moby Project - a collaborative project for the container ecosystem to assemble container-based systems                             
- [rkt](https://github.com/rkt/rkt): [Project ended] rkt is a pod-native container engine for Linux. It is composable, secure, and built on standards.                        
- [pouch](https://github.com/alibaba/pouch): An Efficient Enterprise-class Container Engine

### 容器编排
- [kubernetes](https://github.com/kubernetes/kubernetes): Production-Grade Container Scheduling and Management
- [swarm](https://github.com/docker/swarm): Swarm Classic: a container clustering system. Not to be confused with Docker Swarm which is at https://github.com/docker/swarmkit

### 服务发现
- [consul](https://github.com/hashicorp/consul): Consul is a distributed, highly available, and data center aware solution to connect and configure applications across dynamic, distributed infrastructure.     

### Function
- [faas](https://github.com/openfaas/faas): OpenFaaS - Serverless Functions Made Simple
- [apex](https://github.com/apex/apex): Old apex/apex
                                         
## DevOps
### Monitor
- [prometheus](https://github.com/prometheus/prometheus): The Prometheus monitoring system and time series database.
- [cadvisor](https://github.com/google/cadvisor): Analyzes resource usage and performance characteristics of running containers.
- [ctop](https://github.com/bcicen/ctop): Top-like interface for container metrics
- [beats](https://github.com/elastic/beats): 🐠 Beats - Lightweight shippers for Elasticsearch & Logstash

### Dev
- [rancher](https://github.com/rancher/rancher): Complete container management platform
- [minikube](https://github.com/kubernetes/minikube): Run Kubernetes locally
- [packer](https://github.com/hashicorp/packer): Packer is a tool for creating identical machine images for multiple platforms from a single source configuration.

## 区块链
- [go-ethereum](https://github.com/ethereum/go-ethereum): Official Go implementation of the Ethereum protocol
- [go-ipfs](https://github.com/ipfs/go-ipfs): IPFS implementation in Go
- [fabric](https://github.com/hyperledger/fabric): Hyperledger Fabric is an enterprise-grade permissioned distributed ledger framework for developing solutions and applications. Its modular and versatile design satisfies a broad range of industry use cases. It offers a unique approach to consensus that enables performance at scale while preserving privacy.

## 人工智能
- [golearn](https://github.com/sjwhitworth/golearn): Machine Learning for Go

## 游戏
- [pixel](https://github.com/faiface/pixel): A hand-crafted 2D game library in Go
- [g3n/engine](https://github.com/g3n/engine): Go 3D Game Engine

## 存储引擎
### K / V 存储
- [bolt](https://github.com/boltdb/bolt): An embedded key/value database for Go.
- [etcd](https://github.com/etcd-io/etcd): Distributed reliable key-value store for the most critical data of a distributed system

### 时序数据库
- [influxdb](https://github.com/influxdata/influxdb): Scalable datastore for metrics, events, and real-time analytics

### 分布式数据库
- [cockroach](https://github.com/cockroachdb/cockroach): CockroachDB - the open source, cloud-native distributed SQL database.
- [tidb](https://github.com/pingcap/tidb): TiDB is an open source distributed HTAP database compatible with the MySQL protocol
### 图形数据库
- [cayley](https://github.com/cayleygraph/cayley): An open-source graph database
 
### 其他
- [noms](https://github.com/attic-labs/noms): The versioned, forkable, syncable database
- [vitess](https://github.com/vitessio/vitess): Vitess is a database clustering system for horizontal scaling of MySQL.

## Web
### Web 框架
- [gin](https://github.com/gin-gonic/gin): Gin is a HTTP web framework written in Go (Golang). It features a Martini-like API with much better performance -- up to 40 times faster. If you need smashing performance, get yourself some Gin.
- [beego](https://github.com/astaxie/beego): beego is an open-source, high-performance web framework for the Go programming language
- [martini](https://github.com/go-martini/martini): Classy web framework for Go
- [echo](https://github.com/labstack/echo): High performance, minimalist Go web framework
- [revel](https://github.com/revel/revel): A high productivity, full-stack web framework for the Go language.
- [go-zero](https://github.com/tal-tech/go-zero): go-zero is a web and rpc framework written in Go. It's born to ensure the stability of the busy sites with resilient design. Builtin goctl greatly improves the development productivity.

### 静态建站工具
- [hugo](https://github.com/gohugoio/hugo): The world’s fastest framework for building websites.

### Web Server
- [caddy](https://github.com/caddyserver/caddy): Fast, multi-platform web server with automatic HTTPS

### 微服务
- [kit](https://github.com/go-kit/kit): A standard library for microservices.
- [istio](https://github.com/istio/istio): Connect, secure, control, and observe services.

## 系统 / 命令行工具
- [ngrok](https://github.com/inconshreveable/ngrok): Introspected tunnels to localhost
- [frp](https://github.com/fatedier/frp): A fast reverse proxy to help you expose a local server behind a NAT or firewall to the internet.
- [gotty](https://github.com/yudai/gotty): Share your terminal as a web application
- [micro](https://github.com/zyedidia/micro): A modern and intuitive terminal-based text editor
- [kcptun](https://github.com/xtaci/kcptun): A Stable & Secure Tunnel based on KCP with N:M multiplexing and FEC. Available for ARM, MIPS, 386 and AMD64
- [wuzz](https://github.com/asciimoo/wuzz): Interactive cli tool for HTTP inspection
- [v2ray-core](https://github.com/v2ray/v2ray-core): A platform for building proxies to bypass network restrictions.
- [termui](https://github.com/gizak/termui): Golang terminal dashboard
- [cow](https://github.com/cyfdecyf/cow): HTTP proxy written in Go. COW can automatically identify blocked sites and use parent proxies to access.
- [teleport](https://github.com/gravitational/teleport): Secure Access for Developers that doesn't get in the way.
- [comcast](https://github.com/tylertreat/comcast): Simulating shitty network connections so you can build better systems.
- [wego](https://github.com/schachmat/wego): weather app for the terminal
- [gogs](https://github.com/gogs/gogs): Gogs is a painless self-hosted Git service
- [fsnotify](https://github.com/fsnotify/fsnotify): Cross-platform file system notifications for Go.

## 中间件
- [traefik](https://github.com/traefik/traefik): The Cloud Native Edge Router
- [nsq](https://github.com/nsqio/nsq): A realtime distributed messaging platform
- [codis](https://github.com/CodisLabs/codis): Proxy based Redis cluster solution supporting pipeline and scaling dynamically
- [logrus](https://github.com/sirupsen/logrus): Structured, pluggable logging for Go.
- [groupcache](https://github.com/golang/groupcache): groupcache is a caching and cache-filling library, intended as a replacement for memcached in many cases.
- [nats](https://github.com/nats-io/nats-server): High-Performance server for NATS, the cloud native messaging system
- rpc
    - [grpc](https://github.com/grpc/grpc-go): The Go language implementation of gRPC. HTTP/2 based RPC
    - [rpcx](https://github.com/smallnest/rpcx): A zero cost, faster multi-language bidirectional microservices framework in Go, like alibaba Dubbo, but with more features, Scale easily. Try it. Test it. If you feel it's better, use it! 𝐉𝐚𝐯𝐚有𝐝𝐮𝐛𝐛𝐨, 𝐆𝐨𝐥𝐚𝐧𝐠有𝐫𝐩𝐜𝐱!
## 测试 / 持续交付
- [drone](https://github.com/drone/drone): Drone is a Container-Native, Continuous Delivery Platform
- [terraform](https://github.com/hashicorp/terraform): Terraform enables you to safely and predictably create, change, and improve infrastructure. It is an open source tool that codifies APIs into declarative configuration files that can be shared amongst team members, treated as code, edited, reviewed, and versioned.
- [goreplay](https://github.com/buger/goreplay): GoReplay is an open-source tool for capturing and replaying live HTTP traffic into a test environment in order to continuously test your system with real data. It can be used to increase confidence in code deployments, configuration changes and infrastructure changes.
- [delve](https://github.com/derekparker/delve): Delve is a debugger for the Go programming language.

## 富媒体
### 图像处理
- [primitive](https://github.com/fogleman/primitive): Reproducing images with geometric primitives.
- [caire](https://github.com/esimov/caire): Content aware image resize library

## 安全
- [vault](https://github.com/hashicorp/vault): A tool for secrets management, encryption as a service, and privileged access management
- [vuls](https://github.com/future-architect/vuls): Agent-less vulnerability scanner for Linux, FreeBSD, Container, WordPress, Programming language libraries, Network devices

## 爬虫
- [goquery](https://github.com/PuerkitoBio/goquery): A little like that j-thing, only in Go.

## 文件操作 / 文件系统
- [transfer.sh](https://github.com/dutchcoders/transfer.sh): Easy and fast file sharing from the command-line.
- [seaweedfs](https://github.com/chrislusf/seaweedfs): SeaweedFS is a simple and highly scalable distributed file system to store and serve billions of files fast!
- [minio](https://github.com/minio/minio): High Performance, Kubernetes Native Object Storage
- [syncthing](https://github.com/syncthing/syncthing): Open Source Continuous File Synchronization
- [rclone](https://github.com/rclone/rclone): "rsync for cloud storage" - Google Drive, Amazon Drive, S3, Dropbox, Backblaze B2, One Drive, Swift, Hubic, Cloudfiles, Google Cloud Storage, Yandex Files

## 与其他编程语言
- [grumpy](https://github.com/google/grumpy): Grumpy is a Python to Go source code transcompiler and runtime.
- [gopherjs](https://github.com/gopherjs/gopherjs): A compiler from Go to JavaScript for running Go code in a browser
- [nvm-windows](https://github.com/coreybutler/nvm-windows): A node.js version management utility for Windows. Ironically written in Go.
- [go-mruby](https://github.com/mitchellh/go-mruby): Go (golang) bindings to mruby.
- [go-php](https://github.com/deuill/go-php): PHP bindings for the Go programming language (Golang)